@@ -236,9 +236,13 @@ void Proj4Projection::init()
 		ASSERT(false);
 	}
 
+
 	methods_["geos"] = &Proj4Projection::geos;
 	methods_["conic"] = &Proj4Projection::conic;
 	methods_["simple"] = &Proj4Projection::simple;
+	
+	
+
 	map<string,  InitMethod >::iterator method = methods_.find(projection_->method_);
 	if ( method != methods_.end() )
 		(this->*method->second)();
@@ -249,6 +253,10 @@ void Proj4Projection::init()
 	helpers_["full"] = &Proj4Projection::full;
 	helpers_["corners"] = &Proj4Projection::corners;
 	helpers_["centre"] = &Proj4Projection::centre;
+	helpers_["projection"] = &Proj4Projection::projectionSimple;
+
+	if ( coordinates_system_ == "projection" ) 
+		setting_ = "projection";
 
 	map<string,  SettingHelper >::iterator helper = helpers_.find(lowerCase(setting_));
 
@@ -416,7 +424,7 @@ void Proj4Projection::conic()
 	}
 	*/
 	// top
-	add( projection_->minlon_, projection_->maxlat_);
+	add( projection_->minlon_ - vertical_longitude_, projection_->maxlat_);
 	for ( int lon = projection_->minlon_; lon <= projection_->maxlon_; lon++) {
 		add(lon, projection_->minlat_);
 	}
@@ -452,6 +460,40 @@ void Proj4Projection::simple()
 	add(projection_->minlon_, projection_->minlat_);
 }
 
+void Proj4Projection::projectionSimple()
+{
+
+		min_pcx_ = min_longitude_;
+		min_pcy_ = min_latitude_;
+		max_pcx_ = max_longitude_;
+		max_pcy_ = max_latitude_;
+		pj_transform(to_, from_, 1, 1, &min_longitude_, &min_latitude_, NULL );
+		pj_transform(to_, from_, 1, 1, &max_longitude_, &max_latitude_, NULL );
+	
+		min_longitude_ *= RAD_TO_DEG;
+		min_latitude_ *= RAD_TO_DEG;
+		max_longitude_ *= RAD_TO_DEG;
+		max_latitude_ *= RAD_TO_DEG;
+	
+		Polyline box;
+		box.box(PaperPoint(min_pcx_, min_pcy_), PaperPoint(max_pcx_, max_pcy_));
+
+		vector<Polyline> newbox;
+		PCEnveloppe_->intersect(box, newbox);
+		if ( newbox.empty() ) {
+			MagLog::warning() << "Proj4 : the sub-area is not valid : use global view instead" << endl;
+		}
+		else {
+			PCEnveloppe_ = newbox.front().clone();
+		}
+		// reset 
+		setting_ = "corners";
+		coordinates_system_ = "latlon";
+	
+}
+
+
+
 void Proj4Projection::geos()
 {
 	userEnveloppe_->clear();
@@ -888,6 +930,32 @@ void Proj4Projection::reprojectComponents(double& x, double& y, pair<double, dou
 	components.second = speed * sin(rotation);
 }
 
+void myprint(double x, double y, bool next = false) 
+{
+	cout << "[" << x << ", " << y << "]";
+	if ( next )
+		cout << "--->";
+	else 
+		cout << endl;
+}
+
+void Proj4Projection::reprojectSpeedDirection(const PaperPoint& point, pair<double, double>& wind) const
+{
+	double x = point.x_;
+	double y =  point.y_;
+
+	double u = x + (  sin( wind.second*DEG_TO_RAD) );
+	double v = y + (  cos( wind.second*DEG_TO_RAD) );
+
+	fast_reproject(x, y);
+	fast_reproject(u, v);
+	
+	double rotation = atan2((u - x), (v - y));
+	
+	wind.second =   (rotation*RAD_TO_DEG);
+	
+}
+
 void Proj4Projection::revert(const vector< std::pair<double, double> > & in, vector< std::pair<double, double> > & out) const
 {
 	const_cast<Proj4Projection*>(this)->init();
